CombRc

Struct CombRc 

pub struct CombRc<T: Clone> { /* private fields */ }
A wrapper around an Rc that clones when mutably borrowed if it is not unique.

Like Rc, this is not thread-safe.

Examples

See the crate documentation for examples.

Implementations

Source

impl<T: Clone> CombRc<T>

pub fn new(what: T) -> CombRc<T>

Constructs a CombRc.

pub fn from_rc(what: Rc<T>) -> CombRc<T>

Constructs a CombRc from an already created Rc.

pub fn clone_unique(what: &CombRc<T>) -> CombRc<T>

Clones the inner value stored in the CombRc, returning a unique clone of it.

pub fn try_unwrap(what: CombRc<T>) -> Result<T, Self>

Attempt to get the inner value inside of the CombRc.

If this is a unique reference, the inner value will be moved. Otherwise, the reference will be re-returned.

pub fn make_inner(what: CombRc<T>) -> T

Try to get the inner value inside of the CombArc or clone otherwise.

If this is a unique reference, the inner value will be moved. Otherwise, it will be cloned.

pub fn get_rc(what: &CombRc<T>) -> &Rc<T>

Get the inner Rc value.