pub struct CombRc<T: Clone> { /* private fields */ }Expand description
Implementations
Sourceimpl<T: Clone> CombRc<T>
impl<T: Clone> CombRc<T>
Sourcepub fn clone_unique(what: &CombRc<T>) -> CombRc<T>
pub fn clone_unique(what: &CombRc<T>) -> CombRc<T>
Clones the inner value stored in the CombRc, returning a unique clone of it.
Sourcepub fn try_unwrap(what: CombRc<T>) -> Result<T, Self>
pub fn try_unwrap(what: CombRc<T>) -> Result<T, Self>
Attempt to get the inner value inside of the CombRc.
If this is a unique reference, the inner value will be moved. Otherwise, the reference will be re-returned.
Sourcepub fn make_inner(what: CombRc<T>) -> T
pub fn make_inner(what: CombRc<T>) -> T
Try to get the inner value inside of the CombArc or clone otherwise.
If this is a unique reference, the inner value will be moved. Otherwise, it will be cloned.